@@ -219,7 +219,7 @@ class Console(cmd.Cmd):
         self.__options.nocolor = True
 
         try:
-            generator = RopChain.get(self.__binaries,split[0], self.__cprinter)
+            generator = RopChain.get(self.__binaries, self.__gadgets,split[0], self.__cprinter)
 
             self.__printInfo('generating rop chain')
             #self.__printSeparator(behind='\n\n')
@@ -280,7 +280,7 @@ class Console(cmd.Cmd):
         self.binary.gadgets = dao.load(self.binary)
         self.binary.loaded = True
 
-        self.__gadgets[self.binary] = ropper.deleteDuplicates(ropper.filterBadBytes(self.binary.gadgets))
+        self.__gadgets[self.binary] = ropper.deleteDuplicates(ropper.filterBadBytes(self.binary.gadgets, self.__options.badbytes))
 
     def __printStrings(self, string, sec=None):
         data = []
